package com.gic.haoban.manage.web.controller;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.web.qo.PageQo;
import com.gic.haoban.base.api.common.PageResult2;
import com.gic.haoban.common.utils.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.common.utils.PageUtil;
import com.gic.haoban.manage.api.dto.notify.dto.NoticeMessageInfoDTO;
import com.gic.haoban.manage.api.dto.notify.dto.PendingTaskDetailDTO;
import com.gic.haoban.manage.api.dto.notify.qdto.PendingListQDTO;
import com.gic.haoban.manage.api.enums.NoticeMessageCategoryTypeEnum;
import com.gic.haoban.manage.api.enums.PendingTaskTypeEnum;
import com.gic.haoban.manage.api.service.notify.NoticeMessageApiService;
import com.gic.haoban.manage.api.service.notify.PendingTaskApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.qo.CommonQO;
import com.gic.haoban.manage.web.qo.PendingListQO;
import com.gic.haoban.manage.web.qo.notify.MessageListQO;
import com.gic.haoban.manage.web.vo.notify.PairValVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created 2021/12/16.
 *
 * @author hua
 */
@RestController
public class NotifyController extends WebBaseController {

    @Autowired
    private PendingTaskApiService pendingTaskApiService;

    @Autowired
    private NoticeMessageApiService noticeMessageService;

    /**
     * 待办列表
     *
     * @return
     */
    @RequestMapping("/commission/list")
    public HaobanResponse pendingList(@RequestBody @Valid PendingListQO qo) {
        PendingListQDTO pendingListQDTO = EntityUtil.changeEntityByOrika(PendingListQDTO.class, qo);
        pendingListQDTO.setFinishFlag(0);
        pendingListQDTO.setOverdueFlag(-1);
        if (qo.getFilterStatus() == 1) {
            pendingListQDTO.setOverdueFlag(1);
        }
        ServiceResponse<Page<PendingTaskDetailDTO>> retPage = pendingTaskApiService.pagePendingTask(pendingListQDTO, qo.getBasePageInfo());

        PageResult2 pageInfo = PageUtil.getPageInfo(retPage.getResult());
        return resultResponse(HaoBanErrCode.ERR_1, pageInfo);
    }

    /**
     * 今日待办列表 最多20条
     *
     * @return
     */
    @RequestMapping("/commission/today-list")
    public HaobanResponse pendingToday(@RequestBody @Valid CommonQO qo) {
        ServiceResponse<List<PendingTaskDetailDTO>> response = pendingTaskApiService
                .listPendingTaskToday(qo.getEnterpriseId(), qo.getStoreId(), qo.getClerkId(), false);
        return resultResponse(HaoBanErrCode.ERR_1, response.getResult());
    }


    /**
     * 今日待办列表 最多20条
     *
     * @return
     */
    @RequestMapping("/commission/filter-info")
    public HaobanResponse filterInfo(@RequestBody @Valid CommonQO qo) {
        Map<String, Object> ret = new HashMap<String, Object>();

        List<PairValVO> taskTypes = new ArrayList<PairValVO>();
        List<PairValVO> filter = new ArrayList<PairValVO>();
        PendingTaskTypeEnum[] values = PendingTaskTypeEnum.values();
        for (PendingTaskTypeEnum val : values) {
            PairValVO vo = new PairValVO();
            vo.setKey(String.valueOf(val.getType()));
            vo.setName(val.getName());
            taskTypes.add(vo);
        }
        {
            PairValVO vo = new PairValVO();
            vo.setKey("0");
            vo.setName("未完成");
            filter.add(vo);
        }
        {
            PairValVO vo = new PairValVO();
            vo.setKey("1");
            vo.setName("已逾期");
            filter.add(vo);
        }
        ret.put("taskTypes", taskTypes);
        ret.put("filter", filter);

        return resultResponse(HaoBanErrCode.ERR_1, ret);
    }


    /**
     * 今日待办列表 最多20条
     *
     * @return
     */
    @RequestMapping("/message/list")
    public HaobanResponse list(@RequestBody @Valid MessageListQO qo) {
        ServiceResponse<Page<NoticeMessageInfoDTO>> retPage = noticeMessageService.pageNoticeMessage(qo.getEnterpriseId(), qo.getStoreId(), qo.getClerkId(), qo.getCategoryType(), qo.getBasePageInfo());
        return resultResponse(HaoBanErrCode.ERR_1, PageUtil.getPageInfo(retPage.getResult()));
    }

    /**
     * 设置单条已读
     *
     * @return
     */
    @RequestMapping("/message/read")
    public HaobanResponse readSingle(Long noticeMessageId) {
        noticeMessageService.updateReadFlagById(noticeMessageId);
        return resultResponse(HaoBanErrCode.ERR_1);
    }

    /**
     * 批量设置已读
     *
     * @return
     */
    @RequestMapping("/message/all-read")
    public HaobanResponse readAll(@RequestBody @Valid MessageListQO qo) {
        noticeMessageService.updateWriteFlagByClerkId(qo.getEnterpriseId(), qo.getClerkId(), qo.getCategoryType());
        return resultResponse(HaoBanErrCode.ERR_1);
    }

    /**
     * 消息类别
     *
     * @return
     */
    @RequestMapping("/message/category")
    public HaobanResponse category(@RequestBody @Valid MessageListQO qo) {
        List<PairValVO> ret = new ArrayList<PairValVO>();
        NoticeMessageCategoryTypeEnum[] values = NoticeMessageCategoryTypeEnum.values();
        for (NoticeMessageCategoryTypeEnum val : values) {
            PairValVO vo = new PairValVO();
            vo.setKey(String.valueOf(val.getType()));
            vo.setName(val.getName());
            ret.add(vo);
        }
        return resultResponse(HaoBanErrCode.ERR_1, ret);
    }


    /**
     * 消息类别
     *
     * @return
     */
    @RequestMapping("/message/count")
    public HaobanResponse messageCount(@RequestBody @Valid MessageListQO qo) {
        ServiceResponse<Integer> ret = noticeMessageService.countUnReadNoticeMessage(qo.getEnterpriseId(), qo.getStoreId(), qo.getClerkId());
        return resultResponse(HaoBanErrCode.ERR_1, ret.getResult());
    }


}
